package meta

import (
	"encoding/json"

	"git.loafle.net/overflow/commons-go/core/util"
)

type MetaNoAuthProbeStatus struct {
	ID         json.Number     `json:"id,Number,omitempty"`
	Key        string          `json:"key,omitempty"`
	Name       string          `json:"name,omitempty"`
	CreateDate *util.Timestamp `json:"createDate,omitempty"`
}

type NoAuthProbeStatusEnum int

const (
	NoAuthProbeStatusEnumACCEPT NoAuthProbeStatusEnum = iota + 1
	NoAuthProbeStatusEnumDENY
	NoAuthProbeStatusEnumPROCESSING
)

var (
	noAuthProbeStatusEnumID = map[NoAuthProbeStatusEnum]string{
		NoAuthProbeStatusEnumACCEPT:     "ACCEPT",
		NoAuthProbeStatusEnumDENY:       "DENY",
		NoAuthProbeStatusEnumPROCESSING: "PROCESSING",
	}

	noAuthProbeStatusEnumKey = map[string]NoAuthProbeStatusEnum{
		"ACCEPT":     NoAuthProbeStatusEnumACCEPT,
		"DENY":       NoAuthProbeStatusEnumDENY,
		"PROCESSING": NoAuthProbeStatusEnumPROCESSING,
	}
)

func (e NoAuthProbeStatusEnum) String() string {
	return noAuthProbeStatusEnumID[e]
}

func ToNoAuthProbeStatusEnum(v *MetaNoAuthProbeStatus) NoAuthProbeStatusEnum {
	return noAuthProbeStatusEnumKey[v.Key]
}

func ToMetaNoAuthProbeStatus(v NoAuthProbeStatusEnum) *MetaNoAuthProbeStatus {
	return &MetaNoAuthProbeStatus{
		Key: noAuthProbeStatusEnumID[v],
	}
}
